# Generated by Django 4.2.2 on 2023-06-29 14:55

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TraceActivite',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('demandeur', models.CharField(max_length=50)),
                ('RAE_concerne', models.CharField(max_length=20)),
                ('service_concerne', models.CharField(max_length=100)),
                ('horodate', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
